# -*- coding: UTF-8 -*-
#
# Получение лицензий из очереди
#

import logger
import status
import tempfile
import os
import writetofile


def main(message):
    log = logger.getLogger()
    log.info('Считываем путь для сохранения лицензии.')

    localPath = message.properties.get('localPath')
    if localPath is None:
        mess = 'Путь для сохранения лицензии не указан.'
        log.warning(mess)
        return status.errorLicense, mess

    log.info('Путь для сохранения лицензии - %s.' % localPath.encode('utf8'))
    fileName = os.path.basename(localPath)
    fileDir = os.path.dirname(localPath)

    log.info('Считываем файл лицензии из тела сообщения.')
    license = message.content
    if license is None:
        mess = 'Файл лицензии не указан в теле сообщения.'
        log.warning(mess)
        return status.errorLicense, mess

    writetofile.main(license, fileDir, fileName)

    log.info('Считываем скрипт, который нужно выполнить после сохранения файла лицензии.')
    script = message.properties.get('script')
    if script is None:
        mess = 'Скрипт применения лицензии не указан.'
        log.warning(mess)
        return status.errorLicense, mess

    scriptDir = tempfile.gettempdir()
    scriptName = 'licenseScript.sh'
    writetofile.main(script, scriptDir, scriptName)
    log.info('Запускаем сохраненный скрипт для применения лицензии.')
    result = os.spawnl(os.P_WAIT, os.path.join(scriptDir, scriptName), "")
    if result == 0:
        os.remove(os.path.join(scriptDir, scriptName))
        return status.OK, 'Файл лицензии применен.'

    mess = 'Ошибка выполнения скрипта для применения лицензии.'
    log.error(mess)
    return status.errorLicense, mess
